@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from ansible.module_utils.hashivault import check_secrets_engines
 from ansible.module_utils.hashivault import hashivault_argspec
 from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_init
@@ -105,20 +106,14 @@ def main():
 def hashivault_db_secret_engine_role(module):
     params = module.params
     client = hashivault_auth_client(params)
-    mount_point = params.get('mount_point')
+    mount_point = params.get('mount_point').strip('/')
     role_file = params.get('role_file')
-    name = params.get('name')
+    name = params.get('name').strip('/')
     state = params.get('state')
     desired_state = dict()
     exists = False
     changed = False
 
-    # do not want a trailing slash in name
-    if name[-1] == '/':
-        name = name.strip('/')
-    if mount_point[-1]:
-        mount_point = mount_point.strip('/')
-
     # if role_file is set, set desired_state to contents
     # else take values from ansible play
     if role_file:
@@ -132,14 +127,9 @@ def hashivault_db_secret_engine_role(module):
         desired_state['db_name'] = params.get('db_name')
 
     # check if engine is enabled
-    try:
-        if (mount_point + "/") not in client.sys.list_mounted_secrets_engines()['data'].keys():
-            return {'failed': True, 'msg': 'secret engine is not enabled', 'rc': 1}
-    except:
-        if module.check_mode:
-            changed = True
-        else:
-            return {'failed': True, 'msg': 'secret engine is not enabled or namespace does not exist', 'rc': 1}
+    changed, err = check_secrets_engines(module, client)
+    if err:
+        return err
 
     # check if role exists
     try:
