@@ -97,7 +97,7 @@ def hashivault_oidc_auth_method_config(module):
     params = module.params
     client = hashivault_auth_client(params)
     changed = False
-    mount_point = params.get('mount_point')
+    mount_point = params.get('mount_point').strip('/')
     desired_state = dict()
     current_state = dict()
     exists = False
@@ -108,10 +108,6 @@ def hashivault_oidc_auth_method_config(module):
     url = params['url']
     verify = params['verify']
 
-    # do not want a trailing slash in mount_point
-    if mount_point[-1]:
-        mount_point = mount_point.strip('/')
-
     if not params.get('oidc_discovery_url'):
         desired_state['oidc_discovery_url'] = ''
     else:
@@ -130,7 +126,9 @@ def hashivault_oidc_auth_method_config(module):
 
     # check if engine is enabled
     try:
-        if (mount_point + "/") not in client.sys.list_auth_methods()['data'].keys():
+        result = client.sys.list_auth_methods()
+        backends = result.get('data', result)
+        if (mount_point + "/") not in backends:
             return {'failed': True, 'msg': 'auth mount is not enabled', 'rc': 1}
     except:
         if module.check_mode:
